@@ -15,6 +15,10 @@ from swh.core.api import (
 )
 
 
+class ExpectedException(Exception):
+    """Another exception class to distinguish error handlers"""
+
+
 # this class is used on the server part
 class RPCTest:
     @remote_api_endpoint("endpoint_url")
@@ -34,6 +38,10 @@ class RPCTest:
     def raise_exception_exc_arg(self):
         raise Exception(Exception("error"))
 
+    @remote_api_endpoint("raises_expectedexc")
+    def raise_expectedexc(self):
+        raise ExpectedException("that was expected")
+
 
 # this class is used on the client part. We cannot inherit from RPCTest
 # because the automagic metaclass based code that generates the RPCClient
@@ -58,6 +66,10 @@ class RPCTest2:
     def raise_typeerror(self):
         return "data"
 
+    @remote_api_endpoint("raises_expectedexc")
+    def raise_expectedexc(self):
+        return "nothing"
+
 
 class RPCTestClient(RPCClient):
     backend_class = RPCTest2
@@ -69,6 +81,10 @@ def app():
     # which is defined in swh/core/pytest_plugin.py
     application = RPCServerApp("testapp", backend_class=RPCTest)
 
+    @application.errorhandler(ExpectedException)
+    def my_expected_error_handler(exception):
+        return error_handler(exception, encode_data_server, status_code=400)
+
     @application.errorhandler(Exception)
     def my_error_handler(exception):
         return error_handler(exception, encode_data_server)
@@ -109,10 +125,14 @@ def test_api_endpoint_args(swh_rpc_client):
     assert res == "egg"
 
 
-def test_api_typeerror(swh_rpc_client):
+def test_api_typeerror(swh_rpc_client, mocker):
+    mocked_capture_exception = mocker.patch("swh.core.api.sentry_sdk.capture_exception")
+
     with pytest.raises(RemoteException) as exc_info:
         swh_rpc_client.raise_typeerror()
 
+    assert mocked_capture_exception.called_once_with(TypeError("Did I pass through?"))
+
     assert exc_info.value.args[0]["type"] == "TypeError"
     assert exc_info.value.args[0]["args"] == ["Did I pass through?"]
     assert (
@@ -128,3 +148,15 @@ def test_api_raise_exception_exc_arg(swh_rpc_client):
     assert exc_info.value.args[0]["type"] == "Exception"
     assert type(exc_info.value.args[0]["args"][0]) == Exception
     assert str(exc_info.value.args[0]["args"][0]) == "error"
+
+
+def test_api_expected_exception_no_sentry_capture(swh_rpc_client, mocker):
+    mocked_capture_exception = mocker.patch("swh.core.api.sentry_sdk.capture_exception")
+
+    with pytest.raises(RemoteException) as exc_info:
+        swh_rpc_client.raise_expectedexc()
+
+    assert not mocked_capture_exception.called
+
+    assert exc_info.value.args[0]["type"] == "ExpectedException"
+    assert exc_info.value.args[0]["args"] == ["that was expected"]
