@@ -122,8 +122,7 @@ documented at https://docs.python.org/3/library/logging.config.html.
 )
 @click.pass_context
 def swh(ctx, log_levels, log_config, sentry_dsn, sentry_debug):
-    """Command line interface for Software Heritage.
-    """
+    """Command line interface for Software Heritage."""
     import signal
 
     import yaml
@@ -133,7 +132,7 @@ def swh(ctx, log_levels, log_config, sentry_dsn, sentry_debug):
     signal.signal(signal.SIGTERM, clean_exit_on_signal)
     signal.signal(signal.SIGINT, clean_exit_on_signal)
 
-    init_sentry(sentry_dsn, debug=sentry_debug)
+    init_sentry(sentry_dsn=sentry_dsn, debug=sentry_debug)
 
     set_default_loglevel: Optional[str] = None
 
